@@ -1,21 +1,8 @@
 /*
-  Copyright 2010 Tobias Koenig <tokoe@kde.org>
-  Copyright 2010 Nicolas Lécureuil <nicolas.lecureuil@free.fr>
+  SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2010 Nicolas Lécureuil <nicolas.lecureuil@free.fr>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "addemailaddressjob.h"
@@ -151,7 +138,7 @@ public:
                     const Akonadi::AgentType agentType = dlg->agentType();
 
                     if (agentType.isValid()) {
-                        Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType, q);
+                        auto *job = new Akonadi::AgentInstanceCreateJob(agentType, q);
                         q->connect(job, &Akonadi::AgentInstanceCreateJob::result, q, [this](KJob *job) {
                             slotResourceCreationDone(job);
                         });
@@ -211,7 +198,7 @@ public:
         item.setPayload<KContacts::Addressee>(contact);
 
         // save the new item in akonadi storage
-        Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(item, addressBook, q);
+        auto *createJob = new Akonadi::ItemCreateJob(item, addressBook, q);
         q->connect(createJob, &Akonadi::ItemCreateJob::result, q, [this](KJob *job) {
             slotAddContactDone(job);
         });
@@ -277,7 +264,7 @@ public:
         }
     }
 
-    AddEmailAddressJob *q = nullptr;
+    AddEmailAddressJob *const q;
     QString mCompleteAddress;
     QString mEmail;
     QString mName;
@@ -300,7 +287,7 @@ AddEmailAddressJob::~AddEmailAddressJob()
 void AddEmailAddressJob::start()
 {
     // first check whether a contact with the same email exists already
-    Akonadi::ContactSearchJob *searchJob = new Akonadi::ContactSearchJob(this);
+    auto *searchJob = new Akonadi::ContactSearchJob(this);
     searchJob->setLimit(1);
     searchJob->setQuery(Akonadi::ContactSearchJob::Email, d->mEmail.toLower(),
                         Akonadi::ContactSearchJob::ExactMatch);
